function [p,data]=nt_dataview(data,p)
%[p,data]=nt_dataview(data,p) - view data sets
%
% 
%  DATA: matrix, struct, file or directory to view
%  P: parameter structure
%  
% 
if nargin < 1; 
    [p,data]=nt_dataview('/');
    return
end
if nargin < 2; p=[]; end
if isempty(data); error('!'); end

verbose=1;

% name to display on dialog or window
if isa(data,'char');
    data_name=data;
elseif isa(data,'struct');
    data_name='structure';
elseif isnumeric(data) %isa(data,'double');
    data_name='matrix';
else
    error('argument should be string, struct, or numeric');
end


%%%%%%%%%%%%%%%%%%%%%%%%   MATRIX  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if isnumeric(data) 
    
    if ~isa(data, 'double')
        warning('converting data to double');
        data=double(data);
    end
    
    nt_whoss;
    if verbose; disp('matrix'); end
    nDims=ndims(data);
    if nDims==2 && (size(data,1)==1 || size(data,2)==1); nDims=1; end
    if nDims>4; nDims=4; end
    
    % positions
    posFig=[0 100, 1000, 400];
    posButton=[50, 20, 100, 25];
    posEdit=[100 70 800 30];
    
    % put up window
    dialogH=figure('Visible','on', 'WindowStyle','normal', 'Name',data_name, 'NumberTitle','off',...
        'Pointer','arrow', 'Position',posFig,'color', [1 1 1], 'KeyPressFcn',@doFigureKeyPress,...
        'IntegerHandle','off', 'CloseRequestFcn' ,@doDelete);
    
    done=0; 
    while ~done
    
        % plot summary statistics for all dimensions
        plot_params.bottom=0.35; plot_params.height=0.5;
        nt_statmatrix(data,plot_params);

        %set(dialogH,'HandleVisibility','callback');
        whichButton=[];
        returnPressed=[];
        escapePressed=[];
        otherKeyPressed=[];

        % create return button
        buttonH=uicontrol('style', 'pushbutton', 'string', 'Return','position', posButton,...
            'KeyPressFcn',@doControlKeyPress, 'Callback',@doButtonPress, 'HorizontalAlignment','center', 'parent', dialogH,...
            'fontSize', 14);


        % create edit box
%         for iDim=1:nDims
%             editString=['1:',num2str(size(data,iDim))]; % full index for that dimension
%             editH(iDim)=uicontrol('Style','edit','String',editString,'position', posEdit{iDim}, 'parent', dialogH,...
%                 'callback', @editCallback, 'foregroundcolor',[1 1 1]*0 );
%         end
% 
        editString=['data=data( 1 : ',num2str(size(data,1))];
        for iDim=2:nDims
            editString=[editString,', 1 : ',num2str(size(data,iDim))]; % full index for that dimension
        end
        editString=[editString,' );'];
        editH=uicontrol('Style','edit','String',editString,'position', posEdit, 'parent', dialogH,...
            'callback', @editCallback, 'foregroundcolor',[1 1 1]*0 );
        % wait for user input
        if ~ ishghandle(dialogH); return; end 
        uiwait(dialogH); 
        if ~ ishghandle(dialogH); return; end

        % act on user input
        if returnPressed % keyboard
            done=1;
        elseif escapePressed % keyboard
            done=1;
        elseif otherKeyPressed % keyboard
            ;
        else
            h=get(dialogH,'CurrentObject');

            if find(h==editH) % one of the edit boxes
                s=get(editH(1),'string');
                try
                   annotation('textbox', [.5 .04 .1 .1], 'string', 'evaluating...', 'fontsize', 14, 'edgecolor', [1 1 1])
                   drawnow
                   eval(s);
                catch
                   beep;
                   warning(['incorrect indexing string: >',s,'<']);
                end
            elseif h==buttonH 
                done=1;
            else
                disp(num2str(h));
                error('unexpected handle')
            end
        end
        clf
    end
    
    if ishghandle(dialogH); delete(dialogH); end
    
    % return data - or not
    if nargout==0; clear data p; end
    if verbose; disp('returning from nt_dataview...'); end
    %return;
 


%%%%%%%%%%%%%%%%%%%%%%%%   STRUCT  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
elseif isa(data, 'struct')
    % struct in workspace
    if verbose; disp('struct'); end
    if isempty(struct); error('''struct'' is empty!'); end
    field_names=fieldnames(data);
    if isempty(field_names); error('structure is empty!'); end
    field_sizes=zeros(numel(field_names),1);
    for k=1:numel(field_names);
        field=getfield(data,field_names{k});
        field_sizes(k)=round(prod(size(field))/1024);
    end
    clear field;
    a=repmat(' (', numel(field_names),1);
    b=cellstr(num2str(field_sizes, '%9d'));
    b=char(b);
    c=[repmat(' Mb)', numel(field_names),1)];
    i=listdlg('liststring',cellstr([char(field_names),a,b,c]),...
        'name', 'Select field in struct:', ...
        'listsize', [600 300], ...
        'OKstring','Select',...
        'PromptString',data_name);
    
    % call this function on the selected field
    if i
        data=getfield(data,field_names{i});
        [p,data]=nt_dataview(data,p); 
        if nargout==0; data=[]; end
        return
    end
    

    
elseif isa(data, 'char') && exist(data,'file')==2

%%%%%%%%%%%%%%%%%%%%%%%%   FILE  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
    if verbose; disp('file'); end
    
    % try to figure out what kind of file
    ismatfile=0;
    try
        % .mat file?
        S=whos('-file',data);
        ismatfile=1;
    catch
        ; % not a mat file
    end
    
    if ismatfile
        S=whos('-file',data);
        var_names=char(S.name);
        var_sizes=round([S.bytes]/1024)';
        a=repmat(' (', size(var_names,1),1);
        b=cellstr(num2str(var_sizes, '%9d'));
        b=char(b);
        c=[repmat(' Mb)', size(var_names,1),1)];
        i=listdlg('liststring',cellstr([var_names,a,b,c]),...
            'name', 'Select variable in file:', ...
            'listsize', [600 300], ...
            'OKstring','Select',...
            'PromptString',data_name);
        if i
            X=load(data,var_names(i,:));
            [p,data]=nt_dataview(X,p);
        end
        if nargout==0; data=[]; end
        return
    end
        
    % select file reader among those available
    has_ft_reader=0; 
    has_sopen=0;
    if 2==exist('ft_read_header');
        has_ft_read_header=1;
    else
        warning('function ft_read_header() not found: download FieldTrip and/or adjust path');
    end
    if 2==exist('sopen');
        has_sopen=1;
    else
        warning('function sopen() not found: download BIOSIG and/or adjust path');
    end
    
    if has_ft_read_header
        isftReadable=0;
        try
            % readable by FieldTrip?
            h=ft_read_header(data);
            isftReadable=1;
        catch
            ; % can't read
        end
    end
    if ~isftReadable & has_sopen
        isBiosigReadable=0;
        try
            % readable by FieldTrip?
            h=sopen(data);
            isBiosigReadable=1;
            sclose(h);
        catch
            ; % can't read
        end
    else
        error('neither ft_read_header() nor sopen() available');
    end
    
    if isftReadable
        h=ft_read_header(data);    
        data=ft_read_data(data)';
        [p,data]=nt_dataview(data,p);
    elseif isBiosigReadable
        h=sopen(data);
        data=sread(h);
        sclose(h);
        [p,data]=nt_dataview(data,p);
    else
        disp(['File >',data,'< is not a matlab file, and FieldTrip and BIOSIG can''t read it']);
    end
    
%%%%%%%%%%%%%%%%%%%%%%%%   DIRECTORY  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
elseif isa(data, 'char') && exist(data, 'dir')==7
    % directory
    if verbose; disp('directory'); end
    
    d=dir(data);
    fnames=char(d.name);
    idx=find(fnames(:,1)~='.');  % remove '.' and '..' and invisible files
    d=d(idx);
    fnames=fnames(idx,:);
    
    % separate directories and files
    didx=find([d.isdir]);
    fidx=find(~[d.isdir]);
    fnames=fnames([didx, fidx],:);
    
   % count files within the directories
    nfiles=zeros(numel(didx),1);
    for k=1:numel(didx)
        dd=dir([data,'/',d(didx(k)).name]);
        fns=char(dd.name);
        idx=find(fns(:,1)~='.');  % remove '.' and '..' and invisible files
        nfiles(k)=numel(idx);
    end
    
    % size of the files
    mbytes=[d(fidx).bytes]'/1024;
   
    % string arrays to put in dialog list
    a=repmat(' (', numel(d),1);
    if numel(didx)>0
        b=cellstr(num2str(nfiles, '%9d'));
    else
        b=[]; % stupid matlab!
    end
    if numel(fidx)>0
        b=[b;cellstr(num2str(mbytes,'%0.1f'))];
    end
    b=char(b);
    c=[repmat(' files)', numel(didx),1); repmat(' Mb)   ', numel(fidx),1)];
     
    % which directory or file is user interested in?
    
    i=listdlg('liststring',cellstr([fnames,a,b,c]),...
        'name', 'Select file:', ...
        'listsize', [300 300], ...
        'OKstring','Select',...
        'PromptString',data_name);
    
    % call this function on that file
    if i
        data=strcat(data,'/',fnames(i,:));
        [p,data]=nt_dataview(data,p);   
    end
else
    disp([data_name,' not found']); 
    if nargout==0; data=[]; end
    return
end


%h=data;
if nargout==0; 
    disp('hereiam');
    clear data p 
end




%%%%%%%%%%%%%%%%%%%%  LOCAL FUNCTIONS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    function doFigureKeyPress(obj, evd)  %#ok
        switch(evd.Key)
            case {'return','space'}
                returnPressed = true;
            case 'escape'
                escapePressed=true;
            otherwise
                otherKeyPressed=true;
        end
        uiresume(gcbf)
    end

    function doDelete(varargin)
        delete(dialogH);
    end

    function editCallback(obj,evd);
        %editString = get(obj,'String');
        uiresume(gcbf);
    end

    function doButtonPress(obj,evd);
        whichButton=obj;
        uiresume(gcbf);
    end



end % this file's main function
